let webpack = require('webpack');

const config = require("./webpack.config");
const merge = require("webpack-merge");

let webpackPromiseResolve;
let webpackPromise = new Promise(function (resolve) {
    webpackPromiseResolve = resolve;
});

let webpackconfig = {
    output: {
        path: light.config.dist,
        filename: 'app.js'
    },
    module: {
        rules: [{
            test: /\.vue$/,
            loader: 'vue-loader',
            options: {
                loaders: {
                    js: "babel-loader?presets[]=es2015&presets[]=stage-0"
                }
            }
        }],
    },
    plugins: [
        new webpack.DefinePlugin({
            'process.env.RUNTIME': JSON.stringify("web"),
            'process.env.NODE_ENV': JSON.stringify(process.env.NODE_ENV),
            '__ENV__':require("./env")(light.options.env || 'default')
        }),
    ]
};

if(process.argv.indexOf("--native")<0 && (!light.config.plugins || light.config.plugins.indexOf("jsnative")<0)){
}else{
    webpackconfig.module.rules[0].options.compilerModules = [{
        postTransformNode: el => {
            el.staticStyle = `$processStyle(${el.staticStyle})`
            el.styleBinding = `$processStyle(${el.styleBinding})`
        }
    }];

    webpackconfig = merge({
        entry: {
            app: [
                `${__dirname}/weex.init.js`,
            ]
        }
    }, webpackconfig)
}



if (process.env.NODE_ENV === "dev") {
    webpackconfig = merge({
        devtool: 'source-map',
        entry: {
            app: ['webpack-hot-middleware/client?path=/__webpack_hmr&timeout=20000']
        },
        plugins: [
            new webpack.HotModuleReplacementPlugin({
                multiStep: false,
            }),
            new webpack.NoEmitOnErrorsPlugin()
        ]
    }, webpackconfig)
}

// 61306【lighting】再增加一个参数单独控制是否开启vConsole
if (light.options.console) {
    webpackconfig = merge({
        entry: {
            app: [`${__dirname}/plugins/vconsole.js`]
        }
    }, webpackconfig)
}


module.exports = {
    build() {
        // 59972 【lighting】可以考虑在现有约定的基础上开放自定义配置接口（Webpack和Babel）
        let distConfig = merge(webpackconfig,config);
        let buildJS = require("path").join(light.config.src,"build.js");
        if(require("fs").existsSync(buildJS)){
            distConfig = require(buildJS).build(distConfig,merge,webpack)
        }

        let compiler = webpack(distConfig, function (err, stats) {
            if (err) throw err;
            webpackPromiseResolve()
        });
        return {
            compiler,
            webpackPromise
        };
    }
};